@@ -4,8 +4,9 @@ from __future__ import absolute_import, print_function
 import math
 import operator
 from functools import reduce
+from suanpan.lazy_import import lazy_import
 
-import numpy as np
+np = lazy_import('numpy')
 
 
 def toND(data, n):
